django_auxilium.forms package
=============================

.. automodule:: django_auxilium.forms
    :members:
    :undoc-members:
    :show-inheritance:

Submodules
----------

.. toctree::

   django_auxilium.forms.color
   django_auxilium.forms.files
   django_auxilium.forms.multiple_values
   django_auxilium.forms.range

